@@ -270,14 +270,17 @@ class HttpTransit:
         """
             Metodo para iniciar el servidor HTTP
         """
-        DEBUG = True
+        # DEBUG = True
+
         # Validar si es produccion
         if os.environ.get('PRODUCTION', None):
-            DEBUG = False
+            # DEBUG = False
+            pass
 
         self.logs.info('REST ENABLED: True')
 
         serve(self._app, host=self._host, port=self._port)
 
         # Iniciar el servidor
-        # self._app.run(host=self._host, port=self._port, quiet=True, debug=DEBUG, server='cherrypy')
+        # self._app.run(host=self._host, port=self._port,
+        #              quiet=True, debug=DEBUG)
