@@ -1,15 +1,17 @@
 from .microservices import Microservices
 from .ms_base import KafkaBase
 from .loggs import Loggs
-from .types import Types, TypesActions, Actions
+from .types import Types, TypesActions, Actions, HttpError
 from .options import Options
 from .ErrorMs import ErrorMs
 from .version_framework import version
+from .HttpResponse import HttpResponse
+from .HttpErrors import BadRequest
 
 name = 'MsCoppel'
 
 __all__ = [
-    'Microservices' ,
+    'Microservices',
     'KafkaBase',
     'Loggs',
     'Types',
@@ -17,7 +19,10 @@ __all__ = [
     'MsManager',
     'TypesActions',
     'ErrorMs',
-    'Actions'
+    'Actions',
+    'HttpResponse',
+    'HttpError',
+    'BadRequest',
 ]
 
-__version__ = version
\ No newline at end of file
+__version__ = version
