@@ -754,11 +754,14 @@ class Microservices(BaseClass, ABC):
             # Registro del error
             reg_error = self.___getErrorId(errorCode)
 
-            # Validar si es un string o un objeto de error
-            if isinstance(reg_error, dict):
+            if HTTP is not None:
+                message_error = HTTP.get('message', '')
+
+            if isinstance(reg_error, dict) and message_error == '':
                 message_error = reg_error.get('message', "")
             else:
-                message_error = reg_error
+                if message_error == '':
+                    message_error = reg_error
 
             # Estructura del mensaje de error
             dataResponse['response'] = {
